<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2011-12 Sebastian Fischer <sf@marketing-factory.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Contoller for imports
 *
 * @author Sebastian Fischer <sf@marketing-factory.de>
 */
class Tx_MfcHtmlTag_User_AdditionalLinkTags
{
    /**
     * Configuration
     *
     * @var array
     */
    protected $conf = array();

    /**
     * @var tslib_cObj
     */
    public $cObj;

    /**
     * Render method that gets called by typoscript for adding the meta tag to <head>
     *
     * @param string $content
     * @param array $conf
     * @return string
     */
    public function render($content, $conf)
    {
        $this->conf = $conf;


        if ($conf['link.']) {
            if (!isset($this->pageRenderer)) {
                /** @var tslib_fe $frontend */
                $frontend = $GLOBALS['TSFE'];
                /** @var $pageRenderer t3lib_pageRenderer */
                $this->pageRenderer = $frontend->getPageRenderer();
            }

            foreach ($conf['link.'] as $key => $type) {
                if (strpos($key, '.') === false) {
                    $config = $conf['link.'][$key . '.'];
                    $content = str_replace(array('"', '\''), '', $this->cObj->cObjGetSingle($type, $config));
                    $isUrl = isset($conf['link.'][$key . '.']['isUrl']) ? $conf['link.'][$key . '.']['isUrl'] : 0;
                    if (!empty($content)) {
                        $this->pageRenderer->addMetaTag(
                            '<link rel="' . $key . '" href="' . ((!$isUrl) ?
                                (rtrim($this->getHost(), '/') . '/') : '') . ltrim($content, '/') . '"/>'
                        );
                    }
                }
            }
        }
    }

    /**
     * Get the host part of the canonical tag either by base url or by http host
     *
     * @return string
     */
    protected function getHost()
    {
        if (isset($this->conf['host']) && !empty($this->conf['host'])) {
            $host = $this->conf['host'];
        } else {
            $host = $GLOBALS['TSFE']->baseUrl ? $GLOBALS['TSFE']->baseUrl : 'http://' . $_SERVER['HTTP_HOST'];

        }
        return $host;
    }


    /**
     * Render the touch icons
     *
     * @param string $content
     * @param array $conf
     * @return string
     */
    public function renderAppleTouchIcons($content, $conf)
    {
        $this->conf = $conf;
        if (isset($this->conf['apple-touch-icons.']['enable']) &&
            $this->conf['apple-touch-icons.']['enable'] &&
            isset($this->conf['apple-touch-icons.']['imageObject.']['file'])
        ) {
            if (!isset($this->pageRenderer)) {
                /** @var tslib_fe $frontend */
                $frontend = $GLOBALS['TSFE'];
                /** @var $pageRenderer t3lib_pageRenderer */
                $this->pageRenderer = $frontend->getPageRenderer();
            }
            $config = $this->conf['apple-touch-icons.']['imageObject.'];
            $type = $this->conf['apple-touch-icons.']['imageObject'];
            $imageSizes = explode(',', $this->conf['apple-touch-icons.']['sizes']);

            foreach ($imageSizes as $size) {
                $config['file.']['maxW'] = $size;

                $image = $this->cObj->cObjGetSingle($type, $config);

                if (!empty($image)) {
                    $this->pageRenderer->addMetaTag(
                        '<link rel="apple-touch-icon" sizes="'. $size  . 'x' . $size .'"  href="' .
                        (rtrim($this->getHost(), '/') . '/')  . ltrim($image, '/') . '"/>'
                    );
                }
            }
        }
    }
}
