<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2011-12 Sebastian Fischer <sf@marketing-factory.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Contoller for imports
 *
 * @author Sebastian Fischer <sf@marketing-factory.de>
 */
class Tx_MfcHtmlTag_User_AdditionalMetaTags {
	/**
	 * @var array
	 */
	protected $conf = array();

	/**
	 * @var tslib_cObj
	 */
	public $cObj;

	/**
	 * Render method that gets called by typoscript for adding the meta tag to <head>
	 *
	 * @param string $content
	 * @param array $conf
	 * @return string
	 */
	public function render($content, $conf) {
		$this->conf = $conf;
		/** @var tslib_fe $frontend */
		$frontend = $GLOBALS['TSFE'];

		if ($conf['meta.']) {
			/** @var $pageRenderer t3lib_pageRenderer */
			$pageRenderer = $frontend->getPageRenderer();

			foreach ($conf['meta.'] as $key => $type) {
				if (strpos($key, '.') === FALSE) {
					$metaName = str_replace('_', ':', $key);
					$config = $conf['meta.'][$key . '.'];
					$content = str_replace(array('"', '\''), '', $this->cObj->cObjGetSingle($type, $config));
					if (!empty($content)) {
						$pageRenderer->addMetaTag('<meta property="' . $metaName . '" content="' . $content . '"/>');
					}
				}
			}
		}
	}

	/**
	 * Get the host part of the canonical tag either by base url or by http host
	 *
	 * @return string
	 */
	protected function getHost() {
		if (isset($this->conf['host']) && !empty($this->conf['host'])) {
			$host = $this->conf['host'];
		} else {
			$host = $GLOBALS['TSFE']->baseUrl ? $GLOBALS['TSFE']->baseUrl : 'http://' . $_SERVER['HTTP_HOST'];
		}
		return $host;
	}

	/**
	 * Render the OpenGraph Image
	 *
	 * @param string $content
	 * @param array $conf
	 * @return string
	 */
	public function renderOgImage($content, $conf) {
		/** @var t3lib_db $database */
		$database = $GLOBALS['TYPO3_DB'];

		$row = $database->exec_SELECTgetSingleRow(
			'*',
			'tt_content',
			'colpos = 0 AND CType in ("textpic", "image") AND (image > 0) AND pid = ' . $GLOBALS['TSFE']->id . $this->cObj->enableFields('tt_content'),
			'',
			'sorting asc'
		);

		if ($row) {
			/** @var \TYPO3\CMS\Core\Resource\FileRepository $fileRepository */
			$fileRepository = t3lib_div::makeInstance('TYPO3\\CMS\\Core\\Resource\\FileRepository');
			$fileObjects = $fileRepository->findByRelation('tt_content', 'image', $row['uid']);
			reset($fileObjects);

			if (($file = current($fileObjects)) instanceof \TYPO3\CMS\Core\Resource\FileInterface) {
				/** @var \TYPO3\CMS\Core\Resource\FileReference $file */
				$content = $file->getPublicUrl();
			}
		}

		return $content;
	}
}